<p align="center"><img src="website/static/img/Hydra-Readme-logo2.svg" alt="logo" width="70%" /></p>

<p align="center">
  <a href="https://pypi.org/project/hydra-core/">
    <img src="https://img.shields.io/pypi/v/hydra-core" alt="PyPI" />
  </a>
  <a href="https://circleci.com/gh/facebookresearch/hydra">
    <img src="https://img.shields.io/circleci/build/github/facebookresearch/hydra?token=af199cd2deca9e70e53776f9ded96284b10687e9" alt="CircleCI" />
  </a>
  <a href="#">
    <img src="https://img.shields.io/pypi/l/hydra-core" alt="PyPI - License" />
  </a>
  <a href="#">
    <img src="https://img.shields.io/pypi/pyversions/hydra-core" alt="PyPI - Python Version" />
  </a>
  <a href="https://pepy.tech/project/hydra-core/month?versions=0.11.*&versions=1.0.*">
    <img src="https://pepy.tech/badge/hydra-core/month" alt="Downloads" />
  </a>
  <a href="https://github.com/psf/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code style: black" />
  </a>
  <a href="https://lgtm.com/projects/g/facebookresearch/hydra/alerts/">
    <img src="https://img.shields.io/lgtm/alerts/g/facebookresearch/hydra.svg?logo=lgtm&logoWidth=18" alt="Total alerts" />
  </a>
  <a href="https://lgtm.com/projects/g/facebookresearch/hydra/context:python">
    <img src="https://img.shields.io/lgtm/grade/python/g/facebookresearch/hydra.svg?logo=lgtm&logoWidth=18" alt="Language grade: Python" />
  </a>
  <a href="https://hydra-framework.zulipchat.com">
    <img src="https://img.shields.io/badge/zulip-join_chat-brightgreen.svg" alt="zulip" />
  </a>
  <p align="center">
    <i>A framework for elegantly configuring complex applications.</i>
  </p>
  <p align="center">
    <i>Check the <a href="https://hydra.cc/">website</a> for more information.</i>
  </p>
</p>

----------------------


### Releases
#### Release candidate
**Hydra 1.0** is the next major version of Hydra. It is currently a release candidate and is recommended for all users.
Please report any issues.
- [Release notes](https://github.com/facebookresearch/hydra/releases/tag/hydra-1.0.0rc1)
- [Documentation](https://hydra.cc/docs/next/intro)
- Installation : `pip install hydra-core --upgrade --pre`

#### Stable
**Hydra 0.11** is the stable version of Hydra.
- [Documentation](https://hydra.cc/docs/intro)
- Installation : `pip install hydra-core --upgrade`

### License
Hydra is licensed under [MIT License](LICENSE).

## Community
Ask questions in the chat or StackOverflow (Use the tag #fb-hydra or #omegaconf):
* [Chat](https://hydra-framework.zulipchat.com)
* [StackOverflow](https://stackexchange.com/filters/391828/hydra-questions)
* [Twitter](https://twitter.com/Hydra_Framework)


### Citing Hydra
If you use Hydra in your research please use the following BibTeX entry:
```text
@Misc{Yadan2019Hydra,
  author =       {Omry Yadan},
  title =        {Hydra - A framework for elegantly configuring complex applications},
  howpublished = {Github},
  year =         {2019},
  url =          {https://github.com/facebookresearch/hydra}
}
```

